use std::sync::Arc;

use async_trait::async_trait;

use crate::application::{
    error::post_error::PostError, use_case::get_all_post_info_use_case::GetAllPostInfoUseCase,
};

use super::post_info_response_dto::PostInfoResponseDto;

#[async_trait]
pub trait PostController: Send + Sync {
    async fn get_all_post_info(&self) -> Result<Vec<PostInfoResponseDto>, PostError>;
}

pub struct PostControllerImpl {
    get_all_post_info_use_case: Arc<dyn GetAllPostInfoUseCase>,
}

impl PostControllerImpl {
    pub fn new(get_all_post_info_use_case: Arc<dyn GetAllPostInfoUseCase>) -> Self {
        Self {
            get_all_post_info_use_case,
        }
    }
}

#[async_trait]
impl PostController for PostControllerImpl {
    async fn get_all_post_info(&self) -> Result<Vec<PostInfoResponseDto>, PostError> {
        let result = self.get_all_post_info_use_case.execute().await;

        result.map(|post_info_list| {
            let post_info_response_dto_list: Vec<PostInfoResponseDto> = post_info_list
                .into_iter()
                .map(|post_info| PostInfoResponseDto::from(post_info))
                .collect();

            post_info_response_dto_list
        })
    }
}
