use std::sync::Arc;

use actix_web::{HttpResponse, Responder, web};

use crate::{
    adapter::delivery::post_controller::{PostController, PostControllerImpl},
    application::use_case::get_all_post_info_use_case::GetAllPostInfoUseCase,
};

pub fn configure_post_routes(cfg: &mut web::ServiceConfig) {
    cfg.service(web::resource("/post_info").route(web::get().to(get_all_post_info)));
}

async fn get_all_post_info(
    get_all_post_info_use_case: web::Data<Arc<dyn GetAllPostInfoUseCase>>,
) -> impl Responder {
    let post_controller = PostControllerImpl::new(get_all_post_info_use_case.get_ref().clone());
    let result = post_controller.get_all_post_info().await;

    match result {
        Ok(post_info_list) => HttpResponse::Ok().json(post_info_list),
        Err(_) => HttpResponse::InternalServerError().finish(),
    }
}
